@@ -39,9 +39,17 @@ class Timestamp(abc.ABC):
     def total_seconds(self) -> float:
         raise NotImplementedError
 
+    @property
+    def sec(self) -> float:
+        return self.total_seconds()
+
     def total_milliseconds(self) -> float:
         return self.total_seconds() * MILLISECONDS_PER_SECOND
 
+    @property
+    def ms(self) -> float:
+        return self.total_seconds() * MILLISECONDS_PER_SECOND
+
     def to_datetime(self, timezone: datetime.timezone = None) -> datetime.datetime:
         timezone = datetime.timezone.utc if timezone is None else timezone
         return datetime.datetime.fromtimestamp(self.total_seconds(), tz=timezone)
