@@ -8,10 +8,9 @@
 import datetime
 import logging
 
-from .timestamp import Timestamp
+from .timestamp import Timestamp, MILLISECONDS_PER_SECOND
 
 logger = logging.getLogger(__name__)
-MILLISECONDS_PER_SECOND = 1000
 
 
 class TimestampMs(Timestamp, int):
@@ -27,4 +26,4 @@ class TimestampMs(Timestamp, int):
         return int.__new__(cls, value)
 
     def total_seconds(self) -> float:
-        return self / MILLISECONDS_PER_SECOND
+        return float(self / MILLISECONDS_PER_SECOND)
