@@ -8,10 +8,9 @@
 import datetime
 import logging
 
-from .timestamp import Timestamp
+from .timestamp import Timestamp, MILLISECONDS_PER_SECOND
 
 logger = logging.getLogger(__name__)
-MILLISECONDS_PER_SECOND = 1000
 
 
 class TimestampSec(Timestamp, float):
